package org.jlab.coda.jevio;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;

/**
 * Used for demoing the JEvio library.
 * 
 * @author heddle
 * 
 */
public class Demo implements IEvioListener {

	/**
	 * Main program for testing
	 * 
	 * @param args the command line arguments.
	 */
	public static void main(String args[]) {
		System.out.println("Test of EvioFile class.");

		String cwd = Environment.getInstance().getCurrentWorkingDirectory();

		// assumes we have a directory "testdata" with the test files in the cwd.
//		String testEventFile = cwd + "\\testdata\\dennis.ev";
//		String testEventFile = cwd + "\\testdata\\out.ev";
//		String testDictFile = cwd + "\\testdata\\eviodict.xml";
        String testEventFile = cwd + File.separator + "testdata" + File.separator + "out.ev";
        String testDictFile  = cwd + File.separator + "testdata" + File.separator + "eviodict.xml";

		EvioFile evioFile = null;

		try {
			File file = new File(testEventFile);
			System.out.println("ev file: " + testEventFile + " size: " + file.length());

			evioFile = new EvioFile(testEventFile);
			
			// uncomment below to test a filter
//			IEvioFilter myFilter = new IEvioFilter() {
//				@Override
//				public boolean accept(StructureType structureType, BaseStructureHeader structureHeader) {
//					DataType dataType = structureHeader.getDataTypeEnum();
//					
//					return (dataType == DataType.DOUBLE64);
//				}
//			};
//			EventParser.getInstance().setEvioFilter(myFilter);

			
			//add myself as a listener
			EventParser.getInstance().addEvioListener(new Demo());

			// create a dictionary, set the global name provider
			NameProvider.setProvider(NameProviderFactory.createNameProvider(new File(testDictFile)));

			// try a block test
			EvioFileTest.readAllBlockHeadersTest(evioFile);

			// try read all events test
			EvioFileTest.readAllEventsTest(evioFile);

			// just count the blocks
			EvioFileTest.totalBlockCount(evioFile);

			// try processing some events
			EvioFileTest.parseEventsTest(evioFile, 1);
		}
		catch (FileNotFoundException e) {
			e.printStackTrace();
			System.exit(1);
		}
		catch (IOException e) {
			e.printStackTrace();
			System.exit(1);
		}

	}

    public void startEventParse(EvioEvent evioEvent) { }

    public void endEventParse(EvioEvent evioEvent) { }

	/**
	 * This IEvioListener has received a structure as the result of an event being parsed.
	 * @param evioEvent the event being parsed.
	 * @param structure the structure that I received. It is a BANK, SEGEMENT
	 * or TAGSEGMENT.
	 */
	@Override
	public void gotStructure(EvioEvent evioEvent, IEvioStructure structure) {

		BaseStructureHeader header = structure.getHeader();

		System.out.println("------------------");
		System.out.println("" + structure);
		
		switch (header.getDataTypeEnum()) {
		case DOUBLE64:
			System.out.println("        DOUBLE VALS");
			double doubledata[] = structure.getDoubleData();
			for (double d : doubledata) {
				System.out.println("         " + d);
			}
			break;
			
		case INT32: case UINT32:
			System.out.println("        INT VALS");
			int intdata[] = structure.getIntData();
			for (int i : intdata) {
				System.out.println("         " + i);
			}
			break;
			
		case CHAR8: case UCHAR8:
			System.out.println("        BYTE VALS");
			byte bytedata[] = structure.getByteData();
			for (byte i : bytedata) {
				System.out.println("         " + i);
			}
			break;
		}

	}

}
