package org.jlab.coda.jevio;

/**
 * This interface allows applications to create filters so that they only recieve certain structures
 * when events are being processed. Below is a filter that accepts any structure that has tag = 400.
 * <pre>
 * IEvioFilter myFilter = new IEvioFilter() {
 *     public boolean accept(StructureType structureType, BaseStructureHeader structureHeader) {
 *         return (structureHeader.getTag() == 400);
 *     }
 * };
 * EventParser.getInstance().setEvioFilter(myFilter);
 * </pre>
 * @author heddle
 *
 */
public interface IEvioFilter {

	/**
	 * @param structureType the structure type, a <code>StructureType</code> enum, of the structure
	 * that was just found, e.g., <code>StructureType.BANK</code>.
	 * @param structureHeader the header for the structure that was just found. From this
	 * header the tag, num, length, and data type are available, so the application can filter
	 * based on those quantities. 
	 * @return <code>true</code> if the structure passes the filter and should be given to the listeners.
	 * @see StructureType
	 */
	public boolean accept(StructureType structureType, BaseStructureHeader structureHeader);
}
