package org.jlab.coda.jevio;

import java.nio.ByteBuffer;
import java.nio.ByteOrder;

/**
 * This the the header for an evio segment structure (<code>EvioSegment</code>). It does not contain the raw data, just the
 * header. 
 * 
 * @author heddle
 * 
 */
public final class SegmentHeader extends BaseStructureHeader {
	
	
	/**
	 * Null constructor.
	 */
	public SegmentHeader() {
	}

	/**
	 * Constructor.
	 * @param tag the tag for the segment header.
	 * @param dataType the data type for the content of the segment.
	 */
	public SegmentHeader(int tag, DataType dataType) {
		super(tag, dataType);
	}

	/**
	 * Constructor.
	 * @param tag the tag for the segment header.
	 * @param dataType the (int) data type for the content of the segment.
	 */
	public SegmentHeader(int tag, int dataType) {
		super(tag, dataType);
	}

    /**
     * {@inheritDoc}
     */
    public int getHeaderLength() {return 1;}

    /**
     * {@inheritDoc}
     */
    protected void toArray(byte[] bArray, int offset, ByteOrder order) {
        if (order == ByteOrder.BIG_ENDIAN) {
            bArray[offset]   = byteValue(tag);
            bArray[offset+1] = byteValue(dataType);
            ByteDataTransformer.shortToBytes(shortValue(length), bArray, offset+2);
        }
        else {
            ByteDataTransformer.shortToBytes(Short.reverseBytes(shortValue(length)), bArray, offset);
            bArray[offset+2] = byteValue(dataType);
            bArray[offset+3] = byteValue(tag);
        }
    }

	/**
	 * Obtain a string representation of the bank header.
	 * 
	 * @return a string representation of the bank header.
	 */
	@Override
	public String toString() {
		StringBuffer sb = new StringBuffer(512);
		sb.append(String.format("segment length: %d\n", length));
		sb.append(String.format("number:         %d\n", number));
		sb.append(String.format("data type:      %s\n", getDataTypeName()));
		sb.append(String.format("tag:            %d\n", tag));
		return sb.toString();
	}
	
	/**
	 * Write myself out a byte buffer. This write is relative--i.e., it uses the current position of the buffer.
	 * 
	 * @param byteBuffer the byteBuffer to write to.
	 * @return the number of bytes written, which for a SegmentHeader is 4.
	 */
	@Override
	public int write(ByteBuffer byteBuffer) {
        if (byteBuffer.order() == ByteOrder.BIG_ENDIAN) {
            byteBuffer.put(byteValue(tag));
            byteBuffer.put(byteValue(dataType));
            byteBuffer.putShort(shortValue(length));
        }
        else {
            byteBuffer.putShort(shortValue(length));
            byteBuffer.put(byteValue(dataType));
            byteBuffer.put(byteValue(tag));
        }
		return 4;
	}


}